Use domain name as network name ==> /etc/hosts can be used directly from the docker.
authorFrantišek Dvořák <valtri@civ.zcu.cz>
Thu, 28 Jan 2016 08:32:26 +0000 (09:32 +0100)
committerFrantišek Dvořák <valtri@civ.zcu.cz>
Thu, 28 Jan 2016 08:32:26 +0000 (09:32 +0100)
docker.sh

index d240176..4c4dff3 100755 (executable)
--- a/docker.sh
+++ b/docker.sh
 #
 # 4) docker overlay network created
 #
# docker network create -d overlay vxlan
 #
 
-DOCKER_network='vxlan'
+DOCKER_network='ics.muni.cz'
 #DOCKER_network='bridge'
@@
 # 4) docker overlay network created
 #
-# docker network create -d overlay vxlan
+# docker network create -d overlay ics.muni.cz
 #
 